==> kimageannotator_0.6.1.orig.tar.gz: kImageAnnotator-0.6.1/translations/kImageAnnotator_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Organizar</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Traer al frente</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Traer adelante</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Enviar atrás</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Enviar al fondo</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Seleccionar esto</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation type="unfinished">Color</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished">Color de texto</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Anchura</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Cerrar otros</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Cerrar todo</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Cerrar todos a la izquierda</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Cerrar todos a la derecha</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>↔:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>↕:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilidad de borde y relleno</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Sin borde ni relleno</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Borde y relleno</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Borde sin relleno</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation type="unfinished">Tamaño de letra</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished">↔:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished">↕:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>180°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Redimensionar imagen</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantener relación de aspecto</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Anchura:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Píxel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Porcentaje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished">Adhesivo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pluma</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcador, rectángulo</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcador, elipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Marcador, pluma</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Flecha doble</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Desenfoque</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Apuntador numérico</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adhesivo</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Organizar</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Traer al frente</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Traer adelante</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Enviar atrás</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Enviar al fondo</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Seleccionar esto</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Parámetros generales</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Ajustes de la imagen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Color del texto</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ancho</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Número de semillas</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Factor de ofuscación</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Sombra del artículo</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Ajustes del elemento</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidad</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Cerrar otros</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Cerrar todo</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Cerrar todos a la izquierda</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Cerrar todos a la derecha</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Selección de herramientas</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Activado</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Cultivos</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Girar</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Modificar el lienzo</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>↔:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>↕:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>En vertical</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>En horizontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilidad de borde y relleno</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Sin borde ni relleno</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Borde y relleno</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Borde sin relleno</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Tamaño de letra</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Negrita</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Subrayado</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efectos de la imagen</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Sin efectos</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Sombra paralela</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Escala de grises</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Invertir el color</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Restringido</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Cuando se activa, obliga al lienzo
a incluir la imagen de fondo.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>anch.:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>alt.:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Color del fondo del lienzo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Girar la imagen</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° en sentido horario</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° en sentido antihorario</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrario</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Los valores positivos giran en el sentido de las agujas del reloj, los negativos en sentido contrario.
La rotación mediante multiplicadores que no sean de 90° puede introducir una pérdida de calidad.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>En horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>En vertical</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>DE ACUERDO</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Girar</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Voltear</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Redimensionar imagen</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantener relación de aspecto</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Anchura:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Píxel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Porcentaje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Pegatina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pluma</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcador, rectángulo</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcador, elipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Marcador, pluma</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Flecha doble</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Desenfoque</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Apuntador numérico</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adhesivo</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelar</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Indicador del texto</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Flecha de texto</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Flecha numérica</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Acercar (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Alejar (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Restaurar el zoom (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Restaurar el zoom</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>Ajustar la imagen</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Ajustar la imagen a la vista (%1)</translation>
    </message>
</context>
</TS>
